Class: Handinger::Models::CreateTask

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/handinger/models/create_task.rb

Direct Known Subclasses

TaskCreateParams

Defined Under Namespace

Modules: Budget

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, budget: nil, stream: nil, task_id: nil, worker_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Handinger::Models::CreateTask for more details.

Parameters:

  • input (String)
  • budget (Symbol, Handinger::Models::CreateTask::Budget) (defaults to: nil)

    Compute budget the worker is allowed to spend on the task. Defaults to ‘standard

  • stream (Boolean) (defaults to: nil)

    Stream the response as server-sent events instead of waiting for the final paylo

  • task_id (String) (defaults to: nil)

    Optional client-provided task id. Reuse this id to add turns to an existing task

  • worker_id (String) (defaults to: nil)

    Worker id the task belongs to. If omitted, a new worker is created on-the-fly us



# File 'lib/handinger/models/create_task.rb', line 39

Instance Attribute Details

#budgetSymbol, ...

Compute budget the worker is allowed to spend on the task. Defaults to ‘standard`.

Returns:



16
# File 'lib/handinger/models/create_task.rb', line 16

optional :budget, enum: -> { Handinger::CreateTask::Budget }

#inputString

Returns:

  • (String)


9
# File 'lib/handinger/models/create_task.rb', line 9

required :input, String

#streamBoolean?

Stream the response as server-sent events instead of waiting for the final payload.

Returns:

  • (Boolean, nil)


23
# File 'lib/handinger/models/create_task.rb', line 23

optional :stream, Handinger::Internal::Type::Boolean

#task_idString?

Optional client-provided task id. Reuse this id to add turns to an existing task.

Returns:

  • (String, nil)


30
# File 'lib/handinger/models/create_task.rb', line 30

optional :task_id, String, api_name: :taskId

#worker_idString?

Worker id the task belongs to. If omitted, a new worker is created on-the-fly using the input as instructions.

Returns:

  • (String, nil)


37
# File 'lib/handinger/models/create_task.rb', line 37

optional :worker_id, String, api_name: :workerId