Class: Handinger::Models::TaskWithTurns::Turn

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/handinger/models/task_with_turns.rb

Defined Under Namespace

Classes: File

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(task:, turns:) ⇒ Object



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/handinger/models/task_with_turns.rb', line 21

class Turn < Handinger::Internal::Type::BaseModel
  # @!attribute id
  #
  #   @return [String]
  required :id, String

  # @!attribute completed_at
  #
  #   @return [String, nil]
  required :completed_at, String, api_name: :completedAt, nil?: true

  # @!attribute credits
  #
  #   @return [Integer]
  required :credits, Integer

  # @!attribute duration_ms
  #
  #   @return [Integer]
  required :duration_ms, Integer, api_name: :durationMs

  # @!attribute files
  #   Files published by this turn.
  #
  #   @return [Array<Handinger::Models::TaskWithTurns::Turn::File>]
  required :files, -> { Handinger::Internal::Type::ArrayOf[Handinger::TaskWithTurns::Turn::File] }

  # @!attribute input
  #
  #   @return [String]
  required :input, String

  # @!attribute input_tokens
  #
  #   @return [Integer]
  required :input_tokens, Integer, api_name: :inputTokens

  # @!attribute output_text
  #
  #   @return [String]
  required :output_text, String, api_name: :outputText

  # @!attribute output_tokens
  #
  #   @return [Integer]
  required :output_tokens, Integer, api_name: :outputTokens

  # @!attribute role
  #
  #   @return [String]
  required :role, String

  # @!attribute seq
  #
  #   @return [Integer]
  required :seq, Integer

  # @!attribute started_at
  #
  #   @return [String]
  required :started_at, String, api_name: :startedAt

  # @!attribute status
  #
  #   @return [String]
  required :status, String

  # @!attribute structured_output
  #   Structured JSON payload when the worker is configured with an output schema.
  #   `null` otherwise.
  #
  #   @return [Hash{Symbol=>Object}, nil]
  required :structured_output,
           Handinger::Internal::Type::HashOf[Handinger::Internal::Type::Unknown],
           api_name: :structuredOutput,
           nil?: true

  # @!attribute task_id
  #
  #   @return [String]
  required :task_id, String, api_name: :taskId

  # @!method initialize(id:, completed_at:, credits:, duration_ms:, files:, input:, input_tokens:, output_text:, output_tokens:, role:, seq:, started_at:, status:, structured_output:, task_id:)
  #   Some parameter documentations has been truncated, see
  #   {Handinger::Models::TaskWithTurns::Turn} for more details.
  #
  #   @param id [String]
  #
  #   @param completed_at [String, nil]
  #
  #   @param credits [Integer]
  #
  #   @param duration_ms [Integer]
  #
  #   @param files [Array<Handinger::Models::TaskWithTurns::Turn::File>] Files published by this turn.
  #
  #   @param input [String]
  #
  #   @param input_tokens [Integer]
  #
  #   @param output_text [String]
  #
  #   @param output_tokens [Integer]
  #
  #   @param role [String]
  #
  #   @param seq [Integer]
  #
  #   @param started_at [String]
  #
  #   @param status [String]
  #
  #   @param structured_output [Hash{Symbol=>Object}, nil] Structured JSON payload when the worker is configured with an output schema. `nu
  #
  #   @param task_id [String]

  class File < Handinger::Internal::Type::BaseModel
    # @!attribute filename
    #
    #   @return [String, nil]
    required :filename, String, nil?: true

    # @!attribute media_type
    #
    #   @return [String]
    required :media_type, String, api_name: :mediaType

    # @!attribute url
    #
    #   @return [String]
    required :url, String

    # @!attribute size
    #
    #   @return [Integer, nil]
    optional :size, Integer

    # @!method initialize(filename:, media_type:, url:, size: nil)
    #   @param filename [String, nil]
    #   @param media_type [String]
    #   @param url [String]
    #   @param size [Integer]
  end
end

Instance Attribute Details

#completed_atString?

Returns:

  • (String, nil)


30
# File 'lib/handinger/models/task_with_turns.rb', line 30

required :completed_at, String, api_name: :completedAt, nil?: true

#creditsInteger

Returns:

  • (Integer)


35
# File 'lib/handinger/models/task_with_turns.rb', line 35

required :credits, Integer

#duration_msInteger

Returns:

  • (Integer)


40
# File 'lib/handinger/models/task_with_turns.rb', line 40

required :duration_ms, Integer, api_name: :durationMs

#filesArray<Handinger::Models::TaskWithTurns::Turn::File>

Files published by this turn.



46
# File 'lib/handinger/models/task_with_turns.rb', line 46

required :files, -> { Handinger::Internal::Type::ArrayOf[Handinger::TaskWithTurns::Turn::File] }

#idString

Returns:

  • (String)


25
# File 'lib/handinger/models/task_with_turns.rb', line 25

required :id, String

#inputString

Returns:

  • (String)


51
# File 'lib/handinger/models/task_with_turns.rb', line 51

required :input, String

#input_tokensInteger

Returns:

  • (Integer)


56
# File 'lib/handinger/models/task_with_turns.rb', line 56

required :input_tokens, Integer, api_name: :inputTokens

#output_textString

Returns:

  • (String)


61
# File 'lib/handinger/models/task_with_turns.rb', line 61

required :output_text, String, api_name: :outputText

#output_tokensInteger

Returns:

  • (Integer)


66
# File 'lib/handinger/models/task_with_turns.rb', line 66

required :output_tokens, Integer, api_name: :outputTokens

#roleString

Returns:

  • (String)


71
# File 'lib/handinger/models/task_with_turns.rb', line 71

required :role, String

#seqInteger

Returns:

  • (Integer)


76
# File 'lib/handinger/models/task_with_turns.rb', line 76

required :seq, Integer

#started_atString

Returns:

  • (String)


81
# File 'lib/handinger/models/task_with_turns.rb', line 81

required :started_at, String, api_name: :startedAt

#statusString

Returns:

  • (String)


86
# File 'lib/handinger/models/task_with_turns.rb', line 86

required :status, String

#structured_outputHash{Symbol=>Object}?

Structured JSON payload when the worker is configured with an output schema. ‘null` otherwise.

Returns:

  • (Hash{Symbol=>Object}, nil)


93
94
95
96
# File 'lib/handinger/models/task_with_turns.rb', line 93

required :structured_output,
Handinger::Internal::Type::HashOf[Handinger::Internal::Type::Unknown],
api_name: :structuredOutput,
nil?: true

#task_idString

Returns:

  • (String)


101
# File 'lib/handinger/models/task_with_turns.rb', line 101

required :task_id, String, api_name: :taskId