Module: Handinger::Models::WorkerRetrieveParams::Stream

Extended by:
Internal::Type::Enum
Defined in:
lib/handinger/models/worker_retrieve_params.rb

Overview

Set to “true” to receive a server-sent event stream that replays all stored messages and then continues with live chunks from the active task (if any) before closing.

Constant Summary collapse

TRUE =
:true
FALSE =
:false

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/handinger/models/worker_retrieve_params.rb', line 42