Class: Handinger::Models::Workers::Webhook

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/handinger/models/workers/webhook.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, url:) ⇒ Object

Some parameter documentations has been truncated, see Handinger::Models::Workers::Webhook for more details.

Parameters:

  • token (String, nil)

    Shared secret sent in the ‘X-Handinger-Token` header on each delivery. `null` wh

  • url (String, nil)

    HTTPS endpoint that receives webhook deliveries when a task completes. ‘null` wh



# File 'lib/handinger/models/workers/webhook.rb', line 22

Instance Attribute Details

#tokenString?

Shared secret sent in the ‘X-Handinger-Token` header on each delivery. `null` when no webhook is configured.

Returns:

  • (String, nil)


13
# File 'lib/handinger/models/workers/webhook.rb', line 13

required :token, String, nil?: true

#urlString?

HTTPS endpoint that receives webhook deliveries when a task completes. ‘null` when no webhook is configured.

Returns:

  • (String, nil)


20
# File 'lib/handinger/models/workers/webhook.rb', line 20

required :url, String, nil?: true