Class: Handinger::Models::CreateTask

Inherits:
CreateWorker show all
Defined in:
lib/handinger/models/create_task.rb

Direct Known Subclasses

TaskCreateParams

Instance Attribute Summary collapse

Attributes inherited from CreateWorker

#instructions, #output_schema, #prompt, #summary, #title, #visibility

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(worker_id:, task_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Handinger::Models::CreateTask for more details.

Parameters:

  • worker_id (String)

    Worker id the task belongs to.

  • task_id (String) (defaults to: nil)

    Optional client-provided task id. Reuse this id to add turns to an existing task



# File 'lib/handinger/models/create_task.rb', line 19

Instance Attribute Details

#task_idString?

Optional client-provided task id. Reuse this id to add turns to an existing task.

Returns:

  • (String, nil)


17
# File 'lib/handinger/models/create_task.rb', line 17

optional :task_id, String, api_name: :taskId

#worker_idString

Worker id the task belongs to.

Returns:

  • (String)


10
# File 'lib/handinger/models/create_task.rb', line 10

required :worker_id, String, api_name: :workerId